﻿'*********************************************************************
' File     : frmDemo.vb
' Function : Simple event-driven VB.NET demo for CPS model BP2595
'*********************************************************************

Public Class frmDemo

    Private WithEvents api As bp2595.Api
    Private WithEvents dev As bp2595.Device

    Private Sub DevErrorHandler(ByVal errcode As Integer) Handles dev.DeviceError
        MsgBox("errcode " & errcode & ": " & bp2595.ErrString(errcode), , "ERROR")
    End Sub

    ' Open API
    Private Sub FormLoad(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        api = New bp2595.Api
        If (api.Open() = False) Then Me.Close() ' open api; terminate app if failed
        Me.Text = "CPS 2595 Demo - API v" & api.Version.ToString
    End Sub
    ' Open device
    Private Sub OpenDevice(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles Me.Shown
        For devaddr As Integer = 0 To 7                         ' Find and open device with lowest device address
            If api.IsDeviceDetected(devaddr) Then
                dev = New bp2595.Device                                     ' Instantiate device
                dev.Open(devaddr, Me)                                       ' Open device (device address = radiobutton tag)
                Dim vmax = dev.GetAttributes.output_max_v                   ' Set range and coarse-adjust stepsize on setpoint scrollbar
                hsSetpoint.Minimum = -vmax
                hsSetpoint.Maximum = vmax + hsSetpoint.LargeChange - 1      '   (Maximum = Max_desired + LargeChange - 1)
                lblSetpointMin.Text = (vmax \ 1000).ToString("-## kV")
                lblSetpointMax.Text = (vmax \ 1000).ToString("+## kV")
                dev.MeterInterval = 100                                         ' Tell device to send meter update every 100 milliseconds
                Exit Sub                                                        ' all done
            End If
        Next
        MsgBox("BP2595 not detected", MsgBoxStyle.OkOnly, "Error")        ' No device found
        Me.Close()
    End Sub
    ' Close device and API
    Private Sub FormClose(ByVal sender As Object, ByVal e As System.Windows.Forms.FormClosingEventArgs) Handles Me.FormClosing
        If dev IsNot Nothing Then
            dev.MeterInterval = 0 ' turn off meter updates
            dev.Close()
            dev = Nothing
        End If
        api.Close()
    End Sub

    ' Meters
    Private Sub UpdateMeters() Handles dev.MetersUpdate
        lblMeterUA.Text = dev.Meters.outUA.ToString
        lblMeterV.Text = (dev.Meters.outV.ToString * 0.001).ToString("#0.00")
        lblMeterDegC.Text = (dev.Meters.DeciDegC * 0.1).ToString("##0.0")
    End Sub

    ' Remote/local mode
    Private Sub RemoteControlChanged(ByVal RemoteControl As Boolean) Handles dev.RemoteControlChange
        grpRemoteControl.Enabled = RemoteControl    ' enable/disable remote control GUI
        lblControlMode.Text = IIf(RemoteControl, "Remote", "Local")
    End Sub

    ' Status --------------------------------
    Private Sub UndervoltageChanged() Handles dev.FaultChange
        chkFault.Checked = dev.Status.Undervoltage Or dev.Status.Failed
    End Sub
    Private Sub OvertempChanged() Handles dev.OvertempChange
        chkOvertemp.Checked = dev.Status.Overtemp
    End Sub

    ' HV enable -----------------------
    Private Sub HandleHvEnableChanged() Handles dev.UsbHvEnableChange, dev.AsyncHvEnableChange
        chkHvEnable.Checked = dev.Status.HVEnabled
    End Sub
    Private Sub ToggleHvEnable(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles chkHvEnable.Click
        dev.HvEnable = Not dev.HvEnable  ' invoke remote control
    End Sub

    ' Setpoint -------------------------------
    Private InhibitPgmSetpoint As Integer = False
    Private Sub ProgramSetpoint(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles hsSetpoint.ValueChanged
        If (InhibitPgmSetpoint = 0) Then dev.Setpoint.Volts = hsSetpoint.Value
    End Sub
    Private Sub SetpointChanged() Handles dev.UsbSetpointChange, dev.AsyncSetpointChange
        lblSetpoint.Text = (dev.Setpoint.Volts * 0.001).ToString("#0.000")              ' display setpoint kV
    End Sub
    Private Sub AsyncSetpointChanged() Handles dev.AsyncSetpointChange
        InhibitPgmSetpoint += 1
        hsSetpoint.Value = dev.Setpoint.Volts   ' host didn't invoke setpoint change, so just sync scrollbar
        InhibitPgmSetpoint -= 1
    End Sub

End Class
